@@ -1,5 +1,5 @@
 #!/usr/bin/python3
-from cerberus import Validator
+from cerberus import Validator, schema_registry
 import argparse
 import json
 import os
@@ -21,15 +21,8 @@ from . import schemas
 __args__ = None
 
 
-def traiter_validation_question_yaml(contenu_yaml, references_validation):
-    schemas_unis = {}
-    for référence in references_validation:
-        schemas_unis = {
-            **schemas_unis,
-            **eval(pkg_resources.read_text(schemas, référence)),
-        }
-
-    v = Validator(schemas_unis)
+def traiter_validation_question_yaml(contenu_yaml, schema):
+    v = Validator(schema)
     v.allow_unknown = True
     v.validate(contenu_yaml)
     erreurs = v.errors
@@ -43,9 +36,24 @@ def traiter_validation_question_yaml(contenu_yaml, references_validation):
 
 
 def valider_schema_yaml_infos_question(contenu_fichier):
-    schemas_à_valider = [schemas.SCHEMAS["base"]]
+    schema_registry.add(
+        "rétroactions", eval(pkg_resources.read_text(schemas, "rétroactions.py"))
+    )
+    schema_registry.add(
+        "question_base", eval(pkg_resources.read_text(schemas, "question_base.py"))
+    )
+    schema_registry.add(
+        "question_prog",
+        {
+            **schema_registry.get("question_base"),
+            **eval(pkg_resources.read_text(schemas, "question_prog.py")),
+        },
+    )
+
     if "type" in contenu_fichier and contenu_fichier["type"] == "prog":
-        schemas_à_valider += [schemas.SCHEMAS["prog"]]
+        schemas_à_valider = "question_prog"
+    else:
+        schemas_à_valider = "question_base"
 
     return traiter_validation_question_yaml(contenu_fichier, schemas_à_valider)
 
@@ -166,7 +174,7 @@ def traiter_paramètres():
         "-j",
         "--json",
         action="store_true",
-        help="affiche le résultat et les erreurs/avertissements de validation en format JSON. Par défaut, le résultat est affiché en YAML et les erreurs/avertissements de la validation est en format humainement lisible.",
+        help="affiche le résultat et les erreurs/avertissements de validation en format JSON. Par défaut, le résultat est affiché en YAML et les erreurs/avertissements de la validation est en format humainement lisible.",  # noqa: E501
     )
     parser.add_argument(
         "--strict",
